@@ -1,7 +1,10 @@
+from string import Template
+
 from .tokens import Token
 from .transpiler import transpile
 
-C_CODE = """
+C_CODE = Template(
+"""
 #include <stdio.h>
 
 
@@ -9,13 +12,18 @@ int main(int argc, char **argv) {
     int i = 0;
     char arr[30000];
     memset(arr, 0, sizeof(arr));
-    {}
+    $c_code
+    return 0;
 }
 """
+)
 
 
 def generate(tokens: list[Token]) -> str:
-    return C_CODE.format("\n".join([transpile(token) for token in tokens]))
+    """Generate valid program on C by given tokens"""
+    return C_CODE.substitute(
+        c_code="\n".join([transpile(token) for token in tokens])
+    )
 
 
 __all__ = ["generate"]
